@@ -166,7 +166,9 @@ class DatastoreClient(object):
                 self.transport = transport
         else:
             self.transport = datastore_grpc_transport.DatastoreGrpcTransport(
-                address=api_endpoint, channel=channel, credentials=credentials,
+                address=api_endpoint,
+                channel=channel,
+                credentials=credentials,
             )
 
         if client_info is None:
@@ -258,7 +260,9 @@ class DatastoreClient(object):
             )
 
         request = datastore_pb2.LookupRequest(
-            project_id=project_id, keys=keys, read_options=read_options,
+            project_id=project_id,
+            keys=keys,
+            read_options=read_options,
         )
         if metadata is None:
             metadata = []
@@ -355,7 +359,8 @@ class DatastoreClient(object):
         # Sanity check: We have some fields which are mutually exclusive;
         # raise ValueError if more than one is sent.
         google.api_core.protobuf_helpers.check_oneof(
-            query=query, gql_query=gql_query,
+            query=query,
+            gql_query=gql_query,
         )
 
         request = datastore_pb2.RunQueryRequest(
@@ -447,7 +452,9 @@ class DatastoreClient(object):
             )
 
         request = datastore_pb2.ReserveIdsRequest(
-            project_id=project_id, keys=keys, database_id=database_id,
+            project_id=project_id,
+            keys=keys,
+            database_id=database_id,
         )
         if metadata is None:
             metadata = []
@@ -524,7 +531,8 @@ class DatastoreClient(object):
             )
 
         request = datastore_pb2.BeginTransactionRequest(
-            project_id=project_id, transaction_options=transaction_options,
+            project_id=project_id,
+            transaction_options=transaction_options,
         )
         if metadata is None:
             metadata = []
@@ -621,7 +629,9 @@ class DatastoreClient(object):
 
         # Sanity check: We have some fields which are mutually exclusive;
         # raise ValueError if more than one is sent.
-        google.api_core.protobuf_helpers.check_oneof(transaction=transaction,)
+        google.api_core.protobuf_helpers.check_oneof(
+            transaction=transaction,
+        )
 
         request = datastore_pb2.CommitRequest(
             project_id=project_id,
@@ -705,7 +715,8 @@ class DatastoreClient(object):
             )
 
         request = datastore_pb2.RollbackRequest(
-            project_id=project_id, transaction=transaction,
+            project_id=project_id,
+            transaction=transaction,
         )
         if metadata is None:
             metadata = []
@@ -786,7 +797,10 @@ class DatastoreClient(object):
                 client_info=self._client_info,
             )
 
-        request = datastore_pb2.AllocateIdsRequest(project_id=project_id, keys=keys,)
+        request = datastore_pb2.AllocateIdsRequest(
+            project_id=project_id,
+            keys=keys,
+        )
         if metadata is None:
             metadata = []
         metadata = list(metadata)
